from pathlib import Path


PACKAGE_FOLDER = Path(__file__).parent
ASSETS_FOLDER = PACKAGE_FOLDER / 'assets'


MAPBOX_CSS_URI = 'https://api.mapbox.com/mapbox-gl-js/v2.12.0/mapbox-gl.css'
MAPBOX_JS_URI = 'https://api.mapbox.com/mapbox-gl-js/v2.12.0/mapbox-gl.js'


TURF_JS_URI = (
    'https://cdnjs.cloudflare.com/ajax/libs/Turf.js/6.5.0/turf.min.js')


DECK_JS_URI = 'https://unpkg.com/deck.gl@latest/dist.min.js'
